@@ -10,15 +10,19 @@ class Live(WeverseMedia):
 
     Attributes
     ----------
-    message_count: :class:`int`
-        The number of messages in the live broadcast.
+    message_count: :class:`int` | :class:`None`
+        The number of messages in the live broadcast, if any.
     """
 
     __slots__ = ("message_count",)
 
     def __init__(self, data: dict):
         super().__init__(data)
-        self.message_count: int = data["extension"]["mediaInfo"]["chat"]["messageCount"]
+        self.message_count: int | None = (
+            data["extension"]["mediaInfo"]["chat"]["messageCount"]
+            if data["extension"]["mediaInfo"].get("chat")
+            else None
+        )
 
     def __repr__(self):
         return f"Live live_id={self.id}, title={self.title}"
